@@ -1,141 +1,305 @@
 package Image::Magick::Chart;
 
-# Name:
-#	Image::Magick::Slice.
-#
-# Documentation:
-#	POD-style documentation is at the end. Extract it with pod2html.*.
-#
-# Reference:
-#	Object Oriented Perl
-#	Damian Conway
-#	Manning
-#	1-884777-79-1
-#	P 114
-#
-# Note:
-#	o Tab = 4 spaces || die.
-#
-# Author:
-#	Ron Savage <ron@savage.net.au>
-#	Home page: http://savage.net.au/index.html
-#
-# Licence:
-#	Australian copyright (c) 2005 Ron Savage.
-#
-#	All Programs of mine are 'OSI Certified Open Source Software';
-#	you can redistribute them and/or modify them under the terms of
-#	The Artistic License, a copy of which is available at:
-#	http://www.opensource.org/licenses/index.html
-
 use strict;
 use warnings;
 
 use Carp;
+
 use Image::Magick;
 
-require 5.005_62;
+use Moo;
 
-require Exporter;
+require 5.006002;
 
-our @ISA = qw(Exporter);
+our $VERSION = '1.07';
 
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-
-# This allows declaration	use Image::Magick::Chart ':all';
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
-our %EXPORT_TAGS = ( 'all' => [ qw(
-
-) ] );
-
-our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-
-our @EXPORT = qw(
+use Types::Standard qw/Any ArrayRef Bool Int Str/;
 
+has antialias =>
+(
+	default  => sub{return 0},
+	is       => 'rw',
+	isa      => Bool,
+	required => 0,
+);
+
+has bar_width =>
+(
+	default  => sub{return 8},
+	is       => 'rw',
+	isa      => Int,
+	required => 0,
+);
+
+has bg_color =>
+(
+	default  => sub{return 'white'},
+	is       => 'rw',
+	isa      => Str,
+	required => 0,
+);
+
+has colorspace =>
+(
+	default  => sub{return 'RGB'},
+	is       => 'rw',
+	isa      => Str,
+	required => 0,
+);
+
+has depth =>
+(
+	default  => sub{return 8},
+	is       => 'rw',
+	isa      => Int,
+	required => 0,
+);
+
+has fg_color =>
+(
+	default  => sub{return 'black'},
+	is       => 'rw',
+	isa      => Str,
+	required => 0,
+);
+
+has font =>
+(
+	default  => sub{return 'Courier'},
+	is       => 'rw',
+	isa      => Str,
+	required => 0,
+);
+
+has frame_color =>
+(
+	default  => sub{return 'black'},
+	is       => 'rw',
+	isa      => Str,
+	required => 0,
+);
+
+has frame_option =>
+(
+	default  => sub{return 1},
+	is       => 'rw',
+	isa      => Bool,
+	required => 0,
+);
+
+has height =>
+(
+	default  => sub{return 0},
+	is       => 'rw',
+	isa      => Int,
+	required => 0,
+);
+
+has image =>
+(
+	default  => sub{return ''},
+	is       => 'rw',
+	isa      => Any,
+	required => 0,
+);
+
+has output_file_name =>
+(
+	default  => sub{return ''},
+	is       => 'rw',
+	isa      => Str,
+	required => 1,
+);
+
+has padding =>
+(
+	default  => sub{return [30, 30, 30, 30]}, # [12 noon, 3, 6, 9].
+	is       => 'rw',
+	isa      => ArrayRef,
+	required => 0,
+);
+
+has pointsize =>
+(
+	default  => sub{return 14},
+	is       => 'rw',
+	isa      => Int,
+	required => 0,
+);
+
+has tick_length =>
+(
+	default  => sub{return 4},
+	is       => 'rw',
+	isa      => Int,
+	required => 0,
+);
+
+has title =>
+(
+	default  => sub{return ''},
+	is       => 'rw',
+	isa      => Str,
+	required => 0,
+);
+
+has width =>
+(
+	default  => sub{return 0},
+	is       => 'rw',
+	isa      => Int,
+	required => 0,
+);
+
+has x_axis_data =>
+(
+	default  => sub{return []},
+	is       => 'rw',
+	isa      => ArrayRef,
+	required => 1,
+);
+
+has x_axis_labels =>
+(
+	default  => sub{return []},
+	is       => 'rw',
+	isa      => ArrayRef,
+	required => 1,
+);
+
+has x_axis_labels_option =>
+(
+	default  => sub{return 0},
+	is       => 'rw',
+	isa      => Bool,
+	required => 0,
+);
+
+has x_axis_ticks_option =>
+(
+	default  => sub{return 0},
+	is       => 'rw',
+	isa      => Int, # Sic.
+	required => 0,
+);
+
+has x_data =>
+(
+	default  => sub{return []},
+	is       => 'rw',
+	isa      => ArrayRef,
+	required => 0,
+);
+
+has x_data_option =>
+(
+	default  => sub{return 1},
+	is       => 'rw',
+	isa      => Int,
+	required => 0,
+);
+
+has x_pixels_per_unit =>
+(
+	default  => sub{return 3},
+	is       => 'rw',
+	isa      => Int,
+	required => 0,
+);
+
+has y_axis_data =>
+(
+	default  => sub{return []},
+	is       => 'rw',
+	isa      => ArrayRef,
+	required => 1,
+);
+
+has y_axis_labels =>
+(
+	default  => sub{return []},
+	is       => 'rw',
+	isa      => ArrayRef,
+	required => 1,
+);
+
+has y_axis_labels_option =>
+(
+	default  => sub{return 0},
+	is       => 'rw',
+	isa      => Bool,
+	required => 0,
+);
+
+has y_axis_labels_x =>
+(
+	default  => sub{return undef},
+	is       => 'rw',
+	isa      => Any,
+	required => 0,
+);
+
+has y_axis_ticks_option =>
+(
+	default  => sub{return 1},
+	is       => 'rw',
+	isa      => Int, # Sic.
+	required => 0,
+);
+
+has y_pixels_per_unit =>
+(
+	default  => sub{return 20},
+	is       => 'rw',
+	isa      => Int,
+	required => 0,
 );
-our $VERSION = '1.06';
 
 # -----------------------------------------------
 
-# Preloaded methods go here.
-
-# -----------------------------------------------
-
-# Encapsulated class data.
-
+sub BUILD
 {
-	my(%_attr_data) =
-	(
-	 _antialias            => 0, # 0 => No antialias; 1 => Antialias.
-	 _bar_width            => 8, # Pixels.
-	 _bg_color             => 'white',
-	 _colorspace           => 'RGB',
-	 _depth                => 8, # Bits per channel.
-	 _fg_color             => 'black',
-	 _font                 => 'Courier',
-	 _frame_color          => 'black',
-	 _frame_option         => 1, # 0 => None; 1 => Draw it.
-	 _height               => 0,
-	 _image                => '', # To specify the padding in pixels around the frame
-	 _output_file_name     => '', # I use CSS-style for the 4 sides of the image:
-	 _padding              => [30, 30, 30, 30], # [12 noon, 3, 6, 9].
-	 _pointsize            => 14, # Points.
-	 _tick_length          => 4,  # Pixels.
-	 _title                => '',
-	 _width                => 0,
-	 _x_axis_data          => [],
-	 _x_axis_labels        => [],
-	 _x_axis_labels_option => 1, # 0 => None; 1 => Draw them.
-	 _x_axis_ticks_option  => 2, # 0 => None; 1 => Below x-axis; 2 => Across frame.
-	 _x_data               => [],
-	 _x_data_option        => 1,
-	 _x_pixels_per_unit    => 3, # Horizontal width of each data unit.
-	 _y_axis_data          => [],
-	 _y_axis_labels        => [],
-	 _y_axis_labels_option => 1,     # 0 => None; 1 => Draw them.
-	 _y_axis_labels_x      => undef, # undef => Ignore; Other => Use.
-	 _y_axis_ticks_option  => 1,     # 0 => None; 1 => Left of y-axis; 2 => Across frame.
-	 _y_pixels_per_unit    => 20,
-	);
+	my($self) = @_;
 
-	sub _default_for
+	if ($self -> image)
 	{
-		my($self, $attr_name) = @_;
+		($self -> width, $self -> height) = $self -> image -> Get('width', 'height');
+	}
+	else
+	{
+		$self -> width(${$self -> padding}[3] + 1 + ($self -> x_pixels_per_unit * ${$self -> x_axis_data}[$#{$self -> x_axis_data}]) + ${$self -> padding}[1]);
+		$self -> height(${$self -> padding}[2] + 1 + ($self -> y_pixels_per_unit * ${$self -> y_axis_data}[$#{$self -> y_axis_data}]) + ${$self -> padding}[0]);
+		$self -> image(Image::Magick -> new(size => "$self -> width x $self -> height") );
 
-		$_attr_data{$attr_name};
+		$self -> image -> Set(antialias => $self -> antialias) && Carp::croak("Can't set antialias: $self -> antialias");
+		$self -> image -> Set(colorspace => $self -> colorspace) && Carp::croak("Can't set colorspace: $self -> colorspace");
+		$self -> image -> Set(depth => $self -> depth) && Carp::croak("Can't set depth: $self -> depth");
+		$self -> image -> Read('xc:' . $self -> bg_color) && Carp::croak("Can't set bg_color color: $self -> bg_color");
 	}
 
-	sub _standard_keys
-	{
-		keys %_attr_data;
-	}
-
-}	# End of encapsulated class data.
+}	# End of BUILD.
 
 # -----------------------------------------------
 
 sub draw_frame
 {
 	my($self)  = @_;
-	my($x_max) = $$self{'_x_pixels_per_unit'} * $$self{'_x_axis_data'}[$#{$$self{'_x_axis_data'} }];
+	my($x_max) = $self -> x_pixels_per_unit * ${$self -> x_axis_data}[$#{$self -> x_axis_data}];
 
-	$$self{'_image'} -> Draw
+	$self -> image -> Draw
 	(
-	 fill      => 'none',
-	 primitive => 'polyline',
-	 stroke    => $$self{'_frame_color'},
-	 points    => sprintf
-	 (
-	  "%i,%i %i,%i %i,%i %i,%i %i,%i",
-	  $$self{'_padding'}[3], $$self{'_padding'}[0],
-	  $$self{'_padding'}[3] + $x_max, $$self{'_padding'}[0],
-	  $$self{'_padding'}[3] + $x_max, ($$self{'_height'} - $$self{'_padding'}[2] - 1),
-	  $$self{'_padding'}[3], ($$self{'_height'} - $$self{'_padding'}[2] - 1),
-	  $$self{'_padding'}[3], $$self{'_padding'}[0]
-	 ),
+		fill      => 'none',
+		primitive => 'polyline',
+		stroke    => $self -> frame_color,
+		points    => sprintf
+		(
+			"%i,%i %i,%i %i,%i %i,%i %i,%i",
+			${$self -> padding}[3], ${$self -> padding}[0],
+			${$self -> padding}[3] + $x_max, ${$self -> padding}[0],
+			${$self -> padding}[3] + $x_max, ($self -> height - ${$self -> padding}[2] - 1),
+			${$self -> padding}[3], ($self -> height - ${$self -> padding}[2] - 1),
+			${$self -> padding}[3], ${$self -> padding}[0]
+		),
 	) && Carp::croak("Can't draw frame");
 
 }	# End of draw_frame.
@@ -145,45 +309,45 @@ sub draw_frame
 sub draw_horizontal_bars
 {
 	my($self)           = @_;
-	my($half_bar_width) = int($$self{'_bar_width'} / 2);
-	my($y_zero)         = $$self{'_height'} - $$self{'_padding'}[2] - 1;
+	my($half_bar_width) = int($self -> bar_width / 2);
+	my($y_zero)         = $self -> height - ${$self -> padding}[2] - 1;
 
 	my($i, $data, @metric, $x_right, $y_top);
 
-	for $i (0 .. $#{$$self{'_x_data'} })
+	for $i (0 .. $#{$self -> x_data})
 	{
-		$data    = $$self{'_x_data'}[$i];
-		$x_right = $$self{'_padding'}[3] + ($$self{'_x_pixels_per_unit'} * $data);
-		$y_top   = $y_zero - ($$self{'_y_pixels_per_unit'} * $$self{'_y_axis_data'}[$i]);
+		$data    = ${$self -> x_data}[$i];
+		$x_right = ${$self -> padding}[3] + ($self -> x_pixels_per_unit * $data);
+		$y_top   = $y_zero - ($self -> y_pixels_per_unit * ${$self -> y_axis_data}[$i]);
 
-		$$self{'_image'} -> Draw
+		$self -> image -> Draw
 		(
-			fill      => $$self{'_fg_color'},
+			fill      => $self -> fg_color,
 			primitive => 'polyline',
 			method    => 'floodfill',
-			stroke    => $$self{'_fg_color'},
+			stroke    => $self -> fg_color,
 			points    => sprintf
 			(
-			 "%i,%i %i,%i %i,%i %i,%i",
-			 $$self{'_padding'}[3], $y_top - $half_bar_width,
-			 $x_right, $y_top - $half_bar_width,
-			 $x_right, $y_top + $half_bar_width,
-			 $$self{'_padding'}[3], $y_top + $half_bar_width,
+				"%i,%i %i,%i %i,%i %i,%i",
+				${$self -> padding}[3], $y_top - $half_bar_width,
+				$x_right, $y_top - $half_bar_width,
+				$x_right, $y_top + $half_bar_width,
+				${$self -> padding}[3], $y_top + $half_bar_width,
 			),
 		) && Carp::croak("Can't draw horizontal bars");
 
-		next if ($$self{'_x_data_option'} == 0);
+		next if ($self -> x_data_option == 0);
 
-		@metric = $$self{'_image'} -> QueryFontMetrics(text => $data);
+		@metric = $self -> image -> QueryFontMetrics(text => $data);
 
-		$$self{'_image'} -> Annotate
+		$self -> image -> Annotate
 		(
-		 font        => $$self{'_font'},
+		 font        => $self -> font,
 		 text        => $data,
 		 stroke      => 'black',
 		 strokewidth => 1,
-		 pointsize   => $$self{'_pointsize'},
-		 x           => $x_right + $$self{'_tick_length'},
+		 pointsize   => $self -> pointsize,
+		 x           => $x_right + $self -> tick_length,
 		 y           => $y_top + int($metric[5] / 2) - 2,
 		) && Carp::croak("Can't draw horizontal bars");
 	}
@@ -196,15 +360,15 @@ sub draw_title
 {
 	my($self) = @_;
 
-	$$self{'_image'} -> Annotate
+	$self -> image -> Annotate
 	(
-	 font        => $$self{'_font'},
-	 text        => $$self{'_title'},
+	 font        => $self -> font,
+	 text        => $self -> title,
 	 stroke      => 'black',
 	 strokewidth => 1,
-	 pointsize   => $$self{'_pointsize'},
-	 x           => int( ($$self{'_width'} - int(int($$self{'_pointsize'} / 2) * length($$self{'_title'}) ) ) / 2),
-	 y           => int($$self{'_padding'}[0] / 2) + 2,
+	 pointsize   => $self -> pointsize,
+	 x           => int( ($self -> width - int(int($self -> pointsize / 2) * length($self -> title) ) ) / 2),
+	 y           => int(${$self -> padding}[0] / 2) + 2,
 	) && Carp::croak("Can't draw title");
 
 }	# End of draw_title.
@@ -214,25 +378,25 @@ sub draw_title
 sub draw_x_axis_labels
 {
 	my($self)	= @_;
-	my($x_zero)	= $$self{'_padding'}[3];
+	my($x_zero)	= ${$self -> padding}[3];
 
 	my($i, $text, $x_step, @metric);
 
-	for $i (0 .. $#{$$self{'_x_axis_labels'} })
+	for $i (0 .. $#{$self -> x_axis_labels})
 	{
-		$text   = $$self{'_x_axis_labels'}[$i];
-		$x_step = $x_zero + ($$self{'_x_pixels_per_unit'} * $$self{'_x_axis_data'}[$i]);
-		@metric = $$self{'_image'} -> QueryFontMetrics(text => $text);
+		$text   = ${$self -> x_axis_labels}[$i];
+		$x_step = $x_zero + ($self -> x_pixels_per_unit * ${$self -> x_axis_data}[$i]);
+		@metric = $self -> image -> QueryFontMetrics(text => $text);
 
-		$$self{'_image'} -> Annotate
+		$self -> image -> Annotate
 		(
-			font        => $$self{'_font'},
+			font        => $self -> font,
 			text        => $text,
-			stroke      => $$self{'_frame_color'},
+			stroke      => $self -> frame_color,
 			strokewidth => 1,
-			pointsize   => $$self{'_pointsize'},
+			pointsize   => $self -> pointsize,
 			x           => $x_step - int($metric[4] / 2) - 1,
-			y           => $$self{'_height'} - $$self{'_pointsize'},
+			y           => $self -> height - $self -> pointsize,
 		) && Carp::croak("Can't draw X-axis labels");
 	}
 
@@ -243,20 +407,20 @@ sub draw_x_axis_labels
 sub draw_x_axis_ticks
 {
 	my($self)   = @_;
-	my($x_zero) = $$self{'_padding'}[3];
-	my($y_zero) = $$self{'_x_axis_ticks_option'} == 1 ? $$self{'_height'} - $$self{'_padding'}[2] : $$self{'_padding'}[0];
-	my($y_one)  = $$self{'_height'} - $$self{'_padding'}[2] + $$self{'_tick_length'};
+	my($x_zero) = ${$self -> padding}[3];
+	my($y_zero) = $self -> x_axis_ticks_option == 1 ? $self -> height - ${$self -> padding}[2] : ${$self -> padding}[0];
+	my($y_one)  = $self -> height - ${$self -> padding}[2] + $self -> tick_length;
 
 	my($x, $x_step);
 
-	for $x (@{$$self{'_x_axis_data'} })
+	for $x (@{$self -> x_axis_data})
 	{
-		$x_step = $x_zero + ($$self{'_x_pixels_per_unit'} * $x);
+		$x_step = $x_zero + ($self -> x_pixels_per_unit * $x);
 
-		$$self{'_image'} -> Draw
+		$self -> image -> Draw
 		(
 			primitive => 'line',
-			stroke    => $$self{'_frame_color'},
+			stroke    => $self -> frame_color,
 			points    => sprintf
 			(
 				"%i,%i %i,%i",
@@ -273,23 +437,23 @@ sub draw_x_axis_ticks
 sub draw_y_axis_labels
 {
 	my($self)   = @_;
-	my($y_zero) = $$self{'_height'} - $$self{'_padding'}[2] - 1;
+	my($y_zero) = $self -> height - ${$self -> padding}[2] - 1;
 
 	my($y, $offset, @metric);
 
-	for $y (@{$$self{'_y_axis_labels'} })
+	for $y (@{$self -> y_axis_labels})
 	{
-		@metric = $$self{'_image'} -> QueryFontMetrics(text => $y);
-		$offset	= defined($$self{'_y_axis_labels_x'}) ? $$self{'_y_axis_labels_x'} : $$self{'_padding'}[3] - $$self{'_pointsize'} - $metric[4];
-		$y_zero -= $$self{'_y_pixels_per_unit'};
+		@metric = $self -> image -> QueryFontMetrics(text => $y);
+		$offset	= defined($self -> y_axis_labels_x) ? $self -> y_axis_labels_x : ${$self -> padding}[3] - $self -> pointsize - $metric[4];
+		$y_zero -= $self -> y_pixels_per_unit;
 
-		$$self{'_image'} -> Annotate
+		$self -> image -> Annotate
 		(
-			font        => $$self{'_font'},
+			font        => $self -> font,
 			text        => $y,
-			stroke      => $$self{'_frame_color'},
+			stroke      => $self -> frame_color,
 			strokewidth => 1,
-			pointsize   => $$self{'_pointsize'},
+			pointsize   => $self -> pointsize,
 			x           => $offset,
 			y           => $y_zero + int($metric[5] / 2) - 2,
 		) && Carp::croak("Can't draw Y-axis labels");
@@ -302,10 +466,10 @@ sub draw_y_axis_labels
 sub draw_y_axis_ticks
 {
 	my($self)   = @_;
-	my($x_max)  = $$self{'_x_pixels_per_unit'} * $$self{'_x_axis_data'}[$#{$$self{'_x_axis_data'} }];
-	my($x_zero) = $$self{'_y_axis_ticks_option'} == 1 ? $$self{'_padding'}[3] : $x_max + $$self{'_padding'}[3];
-	my($x_one)  = $$self{'_padding'}[3] - $$self{'_tick_length'};
-	my($y_zero) = $$self{'_height'} - $$self{'_padding'}[2] - 1;
+	my($x_max)  = $self -> x_pixels_per_unit * ${$self -> x_axis_data}[$#{$self -> x_axis_data}];
+	my($x_zero) = $self -> y_axis_ticks_option == 1 ? ${$self -> padding}[3] : $x_max + ${$self -> padding}[3];
+	my($x_one)  = ${$self -> padding}[3] - $self -> tick_length;
+	my($y_zero) = $self -> height - ${$self -> padding}[2] - 1;
 
 	my($i);
 
@@ -315,14 +479,14 @@ sub draw_y_axis_ticks
 	# can - and should - have an empty string as the last
 	# label on the y-axis, to make the image pretty.
 
-	for $i (0 .. $#{$$self{'_x_data'} })
+	for $i (0 .. $#{$self -> x_data})
 	{
-		$y_zero -= $$self{'_y_pixels_per_unit'};
+		$y_zero -= $self -> y_pixels_per_unit;
 
-		$$self{'_image'} -> Draw
+		$self -> image -> Draw
 		(
 			primitive => 'line',
-			stroke    => $$self{'_frame_color'},
+			stroke    => $self -> frame_color,
 			points    => sprintf
 			(
 				"%i,%i %i,%i",
@@ -336,52 +500,11 @@ sub draw_y_axis_ticks
 
 # -----------------------------------------------
 
-sub new
-{
-	my($class, %arg) = @_;
-	my($self)        = bless({}, $class);
-
-	for my $attr_name ($self -> _standard_keys() )
-	{
-		my($arg_name) = $attr_name =~ /^_(.*)/;
-
-		if (exists($arg{$arg_name}) )
-		{
-			$$self{$attr_name} = $arg{$arg_name};
-		}
-		else
-		{
-			$$self{$attr_name} = $self -> _default_for($attr_name);
-		}
-	}
-
-	if ($$self{'_image'})
-	{
-		($$self{'_width'}, $$self{'_height'}) = $$self{'_image'} -> Get('width', 'height');
-	}
-	else
-	{
-		$$self{'_width'}  = $$self{'_padding'}[3] + 1 + ($$self{'_x_pixels_per_unit'} * $$self{'_x_axis_data'}[$#{$$self{'_x_axis_data'} }]) + $$self{'_padding'}[1];
-		$$self{'_height'} = $$self{'_padding'}[2] + 1 + ($$self{'_y_pixels_per_unit'} * $$self{'_y_axis_data'}[$#{$$self{'_y_axis_data'} }]) + $$self{'_padding'}[0];
-		$$self{'_image'}  = Image::Magick -> new(size => "$$self{'_width'} x $$self{'_height'}");
-
-		$$self{'_image'} -> Set(antialias => $$self{'_antialias'}) && Carp::croak("Can't set antialias: $$self{'_antialias'}");
-		$$self{'_image'} -> Set(colorspace => $$self{'_colorspace'}) && Carp::croak("Can't set colorspace: $$self{'_colorspace'}");
-		$$self{'_image'} -> Set(depth => $$self{'_depth'}) && Carp::croak("Can't set depth: $$self{'_depth'}");
-		$$self{'_image'} -> Read("xc:$$self{'_bg_color'}") && Carp::croak("Can't set bg_color color: $$self{'_bg_color'}");
-	}
-
-	return $self;
-
-}	# End of new.
-
-# -----------------------------------------------
-
 sub write
 {
 	my($self) = @_;
 
-	$$self{'_image'} -> Write($$self{'_output_file_name'}) && Carp::croak("Can't write file");
+	$self -> image -> Write($self -> output_file_name) && Carp::croak("Can't write file");
 
 }	# End of write.
 
@@ -393,11 +516,11 @@ __END__
 
 =head1 NAME
 
-C<Image::Magick::Chart> - Use Image::Magick to create charts.
+Image::Magick::Chart - Use Image::Magick to create charts
 
 =head1 Synopsis
 
-	#!/usr/bin/perl
+	#!/usr/bin/env perl
 
 	use Image::Magick::Chart::HorizontalBars;
 
@@ -476,11 +599,11 @@ help on unpacking and installing each type of distro.
 
 new(...) returns an C<Image::Magick::Chart> object.
 
-This is the class's contructor.
+This is the class contructor.
 
 Usage: Image::Magick::Chart -> new().
 
-Note: Actually, you don't normally do this.
+Note: Actually, you do not normally do this.
 
 Instead, you call: Image::Magick::Chart::HorizontalBars -> new(...) -> draw().
 
@@ -492,7 +615,7 @@ Parameters:
 
 =over 4
 
-=item antialias
+=item o antialias
 
 The value, 0 or 1, is passed to Image::Magick, if this module creates the image.
 
@@ -504,7 +627,7 @@ The default value is 0.
 
 This parameter is optional.
 
-=item bar_width
+=item o bar_width
 
 This is the thickness of the bars, in pixels.
 
@@ -512,7 +635,7 @@ The default value is 8 pixels.
 
 This parameter is optional.
 
-=item bg_color
+=item o bg_color
 
 This is the background color of the image, if this module creates the image.
 
@@ -522,7 +645,7 @@ The default value is 'white'.
 
 This parameter is optional.
 
-=item colorspace
+=item o colorspace
 
 The value, 'RGB' etc, is passed to Image::Magick, if this module creates the image.
 
@@ -530,7 +653,7 @@ See the 'image' option if you wish to use a pre-existing object of type Image::M
 
 This parameter is optional.
 
-=item depth
+=item o depth
 
 This is the number of bits per color channel.
 
@@ -538,7 +661,7 @@ The default value is 8.
 
 This parameter is optional.
 
-=item fg_color
+=item o fg_color
 
 This is the color of the horizontal bars, when using C<Image::Magick::Chart::HorizontalBars>.
 
@@ -546,19 +669,19 @@ The default value is 'black'.
 
 This parameter is optional.
 
-=item font
+=item o font
 
 This is the font used for:
 
 =over 4
 
-=item The x-axis labels
+=item o The x-axis labels
 
-=item The y-axis labels
+=item o The y-axis labels
 
-=item The title on top of the image
+=item o The title on top of the image
 
-=item The labels (values) on top of (to the right of) the horizontal bars
+=item o The labels (values) on top of (to the right of) the horizontal bars
 
 =back
 
@@ -566,7 +689,7 @@ The default value is 'Courier'.
 
 This parameter is optional.
 
-=item frame_color
+=item o frame_color
 
 This is the color used to draw a frame around the area of the image which is
 actually occupied by the data.
@@ -575,7 +698,7 @@ The default color is 'black'.
 
 This parameter is optional.
 
-=item frame_option
+=item o frame_option
 
 The value, 0 or 1, determines whether (1) or not (0) the frame will be drawn.
 
@@ -583,7 +706,7 @@ The default value is 1.
 
 This parameter is optional.
 
-=item height
+=item o height
 
 This is the calculated height of the image, taking into account the area occupied by
 the data (the framed area), and the padding on the 4 sides of the frame.
@@ -593,7 +716,7 @@ values for width and height from that image.
 
 This parameter is optional.
 
-=item image
+=item o image
 
 This is the object of type Image::Magick used to manage the image.
 
@@ -604,13 +727,13 @@ If you use you own object, I assume you have set these parameters for your image
 
 =over 4
 
-=item antialias
+=item o antialias
 
-=item bg_color
+=item o bg_color
 
-=item colorspace
+=item o colorspace
 
-=item depth
+=item o depth
 
 =back
 
@@ -619,7 +742,7 @@ in a pre-existing object.
 
 This parameter is optional.
 
-=item output_file_name
+=item o output_file_name
 
 This is the path, filename and extension to the file where the image will be written.
 
@@ -627,7 +750,7 @@ There is no default.
 
 This parameter is mandatory.
 
-=item padding
+=item o padding
 
 This is a array ref of values, in pixels, to leave on all 4 sides of the image, between
 the edge of the image and the part occupied by data (the framed part).
@@ -638,22 +761,22 @@ A clockface is used to define the meanings of the 4 values, thus:
 
 =over 4
 
-=item $$padding[0], the first value, is at the top of the frame
+=item o $$padding[0], the first value, is at the top of the frame
 
 Top corresponds to 12 noon.
 
-=item $$padding[1], the second value, is at the right of the frame
+=item o $$padding[1], the second value, is at the right of the frame
 
 Right corresponds to 3 pm.
 
-Or, if you prefer 3 am, and you think in Spanish, then it's the hour beloved by facists
+Or, if you prefer 3 am, and you think in Spanish, then it is the hour beloved by facists
 and other psychopaths: 'de la madrugada'.
 
-=item $$padding[2], the third value, is at the bottom of the frame
+=item o $$padding[2], the third value, is at the bottom of the frame
 
 Bottom corresponds to 6 pm.
 
-=item $$padding[3], the fourth value, is at the left of the frame
+=item o $$padding[3], the fourth value, is at the left of the frame
 
 Left corresponds to 9 pm.
 
@@ -663,7 +786,7 @@ The default value is [30, 30, 30, 30].
 
 This parameter is optional.
 
-=item pointsize
+=item o pointsize
 
 This is the size of the text used wherever the 'font' option is used.
 
@@ -671,7 +794,7 @@ The default value is 14.
 
 This parameter is optional.
 
-=item tick_length
+=item o tick_length
 
 This is the length, in pixels, of the tick marks on the x and y axes.
 
@@ -679,7 +802,7 @@ The default value is 4 pixels.
 
 This parameter is optional.
 
-=item title
+=item o title
 
 This is the text written at the top centre of the image.
 
@@ -687,7 +810,7 @@ The default value is '' (the empty string).
 
 This parameter is optional.
 
-=item width
+=item o width
 
 This is the calculated width of the image, taking into account the area occupied by
 the data (the framed area), and the padding on the 4 sides of the frame.
@@ -697,7 +820,7 @@ values for width and height from that image.
 
 This parameter is optional.
 
-=item x_axis_data
+=item o x_axis_data
 
 This is an array ref of X values (abscissas) where you want the x-axis labels and x-axis tick marks
 to be drawn.
@@ -712,7 +835,7 @@ This parameter is optional.
 
 Warning: Do not confuse this parameter with the x_data parameter.
 
-=item x_axis_labels
+=item o x_axis_labels
 
 This is an array ref of labels to draw below the x-axis. The X values - around which these
 labels are centered - are supplied by the value of the x_axis_data option.
@@ -724,7 +847,7 @@ The default value is [], meaning no labels are drawn below the x-axis.
 
 This parameter is optional.
 
-=item x_axis_labels_option
+=item o x_axis_labels_option
 
 The value, 0 or 1, determines whether (1) or not (0) the x-axis labels will be drawn.
 
@@ -732,23 +855,23 @@ The default value is 1.
 
 This parameter is optional.
 
-=item x_axis_ticks_option
+=item o x_axis_ticks_option
 
 Values:
 
 =over 4
 
-=item '0'
+=item o 0
 
 Do not draw x-axis tick marks.
 
 The quotes are just to stop the zero disappearing when POD is converted to HTML.
 
-=item 1
+=item o 1
 
 Draw x-axis tick marks below the x-axis.
 
-=item 2
+=item o 2
 
 Draw x-axis tick marks across the frame and below the x-axis.
 
@@ -761,7 +884,7 @@ The default value is 1.
 
 This parameter is optional.
 
-=item x_data
+=item o x_data
 
 This is the array ref of data to use to draw the horizontal bars.
 
@@ -770,7 +893,7 @@ be turned off with the x_data_option parameter.
 
 This parameter is optional.
 
-=item x_data_option
+=item o x_data_option
 
 The value, 0 or 1, determines whether (1) or not (0) the X values given by
 the x_data parameter will be drawn on top of (to the right of) the bars.
@@ -779,7 +902,7 @@ The default value is 1.
 
 This parameter is optional.
 
-=item x_pixels_per_unit
+=item o x_pixels_per_unit
 
 This is the scaling factor in the x-axis direction.
 
@@ -796,7 +919,7 @@ The 100 comes from max(last value in @$x_axis_data, last value in @$x_data).
 
 This parameter is optional.
 
-=item y_axis_data
+=item o y_axis_data
 
 This is an array ref of Y values (ordinates) where you want the y-axis labels and y-axis tick marks
 to be drawn.
@@ -816,7 +939,7 @@ y-axis.
 
 This parameter is optional.
 
-=item y_axis_labels
+=item o y_axis_labels
 
 This is an array ref of labels to draw left of the y-axis. The Y values where these labels
 are drawn is supplied by the value of the y_axis_data option.
@@ -825,7 +948,7 @@ The default value is [], meaning no labels are drawn left of the y-axis.
 
 This parameter is optional.
 
-=item y_axis_labels_option
+=item o y_axis_labels_option
 
 The value, 0 or 1, determines whether (1) or not (0) the y-axis labels will be drawn.
 
@@ -833,7 +956,7 @@ The default value is 1.
 
 This parameter is optional.
 
-=item y_axis_labels_x
+=item o y_axis_labels_x
 
 The value, if not undef, determines the x-axis value (abscissa) at which y-axis labels are written.
 
@@ -847,23 +970,23 @@ The default value is undef.
 
 This parameter is optional.
 
-=item y_axis_ticks_option
+=item o y_axis_ticks_option
 
 Values:
 
 =over 4
 
-=item '0'
+=item o 0
 
 Do not draw y-axis tick marks.
 
 The quotes are just to stop the zero disappearing when POD is converted to HTML.
 
-=item 1
+=item o 1
 
 Draw y-axis tick marks left the y-axis.
 
-=item 2
+=item o 2
 
 Draw y-axis tick marks across the frame and left of the y-axis.
 
@@ -876,7 +999,7 @@ The default value is 1.
 
 This parameter is optional.
 
-=item y_pixels_per_unit
+=item o y_pixels_per_unit
 
 This is the scaling factor in the y-axis direction.
 
@@ -898,72 +1021,92 @@ This parameter is optional.
 
 =back
 
-=head1 Method: draw_frame()
+=head1 Methods
+
+=head2 draw_frame()
 
 Called by method C<draw()> in C<Image::Magick::Chart::HorizontalBars>.
 
 These is no need to call this method yourself.
 
-=head1 Method: draw_horizontal_bars()
+=head2 draw_horizontal_bars()
 
 Called by method C<draw()> in C<Image::Magick::Chart::HorizontalBars>.
 
 These is no need to call this method yourself.
 
-=head1 Method: draw_title()
+=head2 draw_title()
 
 Called by method C<draw()> in C<Image::Magick::Chart::HorizontalBars>.
 
 These is no need to call this method yourself.
 
-=head1 Method: draw_x_axis_labels()
+=head2 draw_x_axis_labels()
 
 Called by method C<draw()> in C<Image::Magick::Chart::HorizontalBars>.
 
 These is no need to call this method yourself.
 
-=head1 Method: draw_x_axis_ticks()
+=head2 draw_x_axis_ticks()
 
 Called by method C<draw()> in C<Image::Magick::Chart::HorizontalBars>.
 
 These is no need to call this method yourself.
 
-=head1 Method: draw_y_axis_labels()
+=head2 draw_y_axis_labels()
 
 Called by method C<draw()> in C<Image::Magick::Chart::HorizontalBars>.
 
 These is no need to call this method yourself.
 
-=head1 Method: draw_y_axis_ticks()
+=head2 draw_y_axis_ticks()
 
 Called by method C<draw()> in C<Image::Magick::Chart::HorizontalBars>.
 
 These is no need to call this method yourself.
 
-=head1 Method: new(...)
+=head2 new(...)
 
 Returns a object of type C<Image::Magick::Chart>.
 
 See above, in the section called 'Constructor and initialization' for details.
 
-=head1 Method: write()
+=head2 write()
 
 Called by method C<draw()> in C<Image::Magick::Chart::HorizontalBars>.
 
 These is no need to call this method yourself.
 
+=head1 Machine-Readable Change Log
+
+The file Changes was converted into Changelog.ini by L<Module::Metadata::Changes>.
+
+=head1 Version Numbers
+
+Version numbers < 1.00 represent development versions. From 1.00 up, they are production versions.
+
+=head1 Repository
+
+L<https://github.com/ronsavage/Image-Magick-Chart>
+
+=head1 Support
+
+Email the author, or log a bug on RT:
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Image-Magick-Chart>.
+
 =head1 Author
 
 C<Image::Magick::Chart> was written by Ron Savage I<E<lt>ron@savage.net.auE<gt>> in 2005.
 
-Home page: http://savage.net.au/index.html
+L<Homepage|http://savage.net.au/>
 
 =head1 Copyright
 
 Australian copyright (c) 2005, Ron Savage.
 	All Programs of mine are 'OSI Certified Open Source Software';
 	you can redistribute them and/or modify them under the terms of
-	The Artistic License, a copy of which is available at:
-	http://www.opensource.org/licenses/index.html
+	The Perl License, a copy of which is available at:
+	http://dev.perl.org/licenses/
 
 =cut
